Package 'BivGeo'

Title: Basu-Dhar Bivariate Geometric Distribution
Description: Provides functions to compute the joint probability mass function (pmf), cumulative distribution function (cdf), and survival function (sf) of the Basu-Dhar bivariate geometric distribution. Additional functionalities include the calculation of the correlation coefficient, covariance, and cross-factorial moments, as well as the generation of random variates. The package also implements parameter estimation based on the method of moments.
Authors: Ricardo Puziol de Oliveira [aut, cre], Jorge Alberto Achcar [aut]
Maintainer: Ricardo Puziol de Oliveira <[email protected]>
License: GPL (>= 2)
Version: 2.1.1
Built: 2026-05-16 06:39:20 UTC
Source: https://github.com/cran/BivGeo

Help Index


Cross-factorial Moment for the Basu-Dhar Bivariate Geometric Distribution

Description

This function computes the cross-factorial moment for the Basu-Dhar bivariate geometric distribution assuming arbitrary parameter values.

Usage

cfbivgeo(theta)

Arguments

theta

vector (of length 3) containing values of the parameters θ1,θ2\theta_1, \theta_2 and θ3\theta_{3} of the Basu-Dhar bivariate Geometric distribution. For real data applications, use the maximum likelihood estimates or Bayesian estimates to get the cross-factorial moment.

Details

The cross-factorial moment between X and Y, assuming the Basu-Dhar bivariate geometric distribution, is given by,

E[XY]=1θ1θ2θ32(1θ1θ3)(1θ2θ3)(1θ1θ2θ3)E[XY] = \frac{1 - \theta_1 \theta_2 \theta_{3}^2}{(1 - \theta_1\theta_3)(1 - \theta_2\theta_3)(1 - \theta_1 \theta_2 \theta_{3})}

Note that the cross-factorial moment is always positive.

Value

cfbivgeo computes the cross-factorial moment for the Basu-Dhar bivariate geometric distribution for arbitrary parameter values.

Invalid arguments will return an error message.

Author(s)

Ricardo P. Oliveira [email protected]

Jorge Alberto Achcar [email protected]

cfbivgeo is calculated directly from the definition.

References

Basu, A. P., & Dhar, S. K. (1995). Bivariate geometric distribution. Journal of Applied Statistical Science, 2, 1, 33-44.

Li, J., & Dhar, S. K. (2013). Modeling with bivariate geometric distributions. Communications in Statistics-Theory and Methods, 42, 2, 252-266.

Achcar, J. A., Davarzani, N., & Souza, R. M. (2016). Basu–Dhar bivariate geometric distribution in the presence of covariates and censored data: a Bayesian approach. Journal of Applied Statistics, 43, 9, 1636-1648.

de Oliveira, R. P., & Achcar, J. A. (2018). Basu-Dhar's bivariate geometric distribution in presence of censored data and covariates: some computational aspects. Electronic Journal of Applied Statistical Analysis, 11, 1, 108-136.

de Oliveira, R. P., Achcar, J. A., Peralta, D., & Mazucheli, J. (2018). Discrete and continuous bivariate lifetime models in presence of cure rate: a comparative study under Bayesian approach. Journal of Applied Statistics, 1-19.

Examples

cfbivgeo(theta = c(0.5, 0.5, 0.7))
# [1] 2.517483
cfbivgeo(theta = c(0.2, 0.5, 0.7))
# [1] 1.829303
cfbivgeo(theta = c(0.8, 0.9, 0.1))
# [1] 1.277864
cfbivgeo(theta = c(0.9, 0.9, 0.9))
# [1] 35.15246

Correlation Coefficient for the Basu-Dhar Bivariate Geometric Distribution

Description

This function computes the correlation coefficient analogous of the Pearson correlation coefficient for the Basu-Dhar bivariate geometric distribution assuming arbitrary parameter values.

Usage

corbivgeo(theta)

Arguments

theta

vector (of length 3) containing values of the parameters θ1,θ2\theta_1, \theta_2 and θ3\theta_{3} of the Basu-Dhar bivariate Geometric distribution. For real data applications, use the maximum likelihood estimates or Bayesian estimates to get the correlation coefficient.

Details

The correlation coefficient between X and Y, assuming the Basu-Dhar bivariate geometric distribution, is given by,

ρ=(1θ3)(θ1θ2)1/21θ1θ2θ3\rho = \frac{(1 - \theta_{3})(\theta_1 \theta_2)^{1/2}}{1 - \theta_1 \theta_2 \theta_{3}}

Note that the correlation coefficient is always positive which implies that the Basu-Dhar bivariate geometric distribution is useful for bivariate lifetimes with positive correlation.

Value

corbivgeo computes the correlation coefficient analogous to the Pearson correlation coefficient for the Basu-Dhar bivariate geometric distribution for arbitrary parameter values.

Invalid arguments will return an error message.

Author(s)

Ricardo P. Oliveira [email protected]

Jorge Alberto Achcar [email protected]

corbivgeo is calculated directly from the definition.

References

Basu, A. P., & Dhar, S. K. (1995). Bivariate geometric distribution. Journal of Applied Statistical Science, 2, 1, 33-44.

Li, J., & Dhar, S. K. (2013). Modeling with bivariate geometric distributions. Communications in Statistics-Theory and Methods, 42, 2, 252-266.

Achcar, J. A., Davarzani, N., & Souza, R. M. (2016). Basu–Dhar bivariate geometric distribution in the presence of covariates and censored data: a Bayesian approach. Journal of Applied Statistics, 43, 9, 1636-1648.

de Oliveira, R. P., & Achcar, J. A. (2018). Basu-Dhar's bivariate geometric distribution in presence of censored data and covariates: some computational aspects. Electronic Journal of Applied Statistical Analysis, 11, 1, 108-136.

de Oliveira, R. P., Achcar, J. A., Peralta, D., & Mazucheli, J. (2018). Discrete and continuous bivariate lifetime models in presence of cure rate: a comparative study under Bayesian approach. Journal of Applied Statistics, 1-19.

Examples

corbivgeo(theta = c(0.5, 0.5, 0.7))
# [1] 0.1818182
corbivgeo(theta = c(0.2, 0.5, 0.7))
# [1] 0.102009
corbivgeo(theta = c(0.8, 0.9, 0.1))
# [1] 0.822926
corbivgeo(theta = c(0.9, 0.9, 0.9))
# [1] 0.3321033

Covariance for the Basu-Dhar Bivariate Geometric Distribution

Description

This function computes the covariance for the Basu-Dhar bivariate geometric distribution assuming arbitrary parameter values.

Usage

covbivgeo(theta)

Arguments

theta

vector (of length 3) containing values of the parameters θ1,θ2\theta_1, \theta_2 and θ3\theta_{3} of the Basu-Dhar bivariate Geometric distribution. For real data applications, use the maximum likelihood estimates or Bayesian estimates to get the covariance.

Details

The covariance between X and Y, assuming the Basu-Dhar bivariate geometric distribution, is given by,

Cov(X,Y)=θ1θ2θ3(1θ3)(1θ1θ3)(1θ2θ3)(1θ1θ2θ3)Cov(X,Y) = \frac{\theta_1 \theta_2 \theta_{3}(1 - \theta_3)}{(1 - \theta_1\theta_3)(1 - \theta_2\theta_3)(1 - \theta_1 \theta_2 \theta_{3})}

Note that the covariance is always positive.

Value

covbivgeo computes the covariance for the Basu-Dhar bivariate geometric distribution for arbitrary parameter values.

Invalid arguments will return an error message.

Author(s)

Ricardo P. Oliveira [email protected]

Jorge Alberto Achcar [email protected]

covbivgeo is calculated directly from the definition.

References

Basu, A. P., & Dhar, S. K. (1995). Bivariate geometric distribution. Journal of Applied Statistical Science, 2, 1, 33-44.

Li, J., & Dhar, S. K. (2013). Modeling with bivariate geometric distributions. Communications in Statistics-Theory and Methods, 42, 2, 252-266.

Achcar, J. A., Davarzani, N., & Souza, R. M. (2016). Basu–Dhar bivariate geometric distribution in the presence of covariates and censored data: a Bayesian approach. Journal of Applied Statistics, 43, 9, 1636-1648.

de Oliveira, R. P., & Achcar, J. A. (2018). Basu-Dhar's bivariate geometric distribution in presence of censored data and covariates: some computational aspects. Electronic Journal of Applied Statistical Analysis, 11, 1, 108-136.

de Oliveira, R. P., Achcar, J. A., Peralta, D., & Mazucheli, J. (2018). Discrete and continuous bivariate lifetime models in presence of cure rate: a comparative study under Bayesian approach. Journal of Applied Statistics, 1-19.

Examples

covbivgeo(theta = c(0.5, 0.5, 0.7))
# [1] 0.1506186
covbivgeo(theta = c(0.2, 0.5, 0.7))
# [1] 0.04039471
covbivgeo(theta = c(0.8, 0.9, 0.1))
# [1] 0.0834061
covbivgeo(theta = c(0.9, 0.9, 0.9))
# [1] 7.451626

Joint Probability Mass Function for the Basu-Dhar Bivariate Geometric Distribution

Description

This function computes the joint probability mass function of the Basu-Dhar bivariate geometric distribution for arbitrary parameter values.

Usage

dbivgeo1(x, y = NULL, theta, log = FALSE)
dbivgeo2(x, y = NULL, theta, log = FALSE)

Arguments

x

matrix or vector containing the data. If x is a matrix then it is considered as x the first column and y the second column (y argument need be setted to NULL). Additional columns and y are ignored.

y

vector containing the data of y. It is used only if x is also a vector. Vectors x and y should be of equal length.

theta

vector (of length 3) containing values of the parameters θ1,θ2\theta_1, \theta_2 and θ3\theta_{3} of the Basu-Dhar bivariate Geometric distribution. The parameters are restricted to 0<θi<1,i=1,20 < \theta_i < 1, i = 1,2 and 0<θ310 < \theta_{3} \le 1.

log

logical argument for calculating the log probability or the probability function. The default value is FALSE.

Details

The joint probability mass function for a random vector (XX, YY) following a Basu-Dhar bivariate geometric distribution could be written in two forms. The first form is described by:

P(X=x,Y=y)=θ1x1θ2y1θ3z1θ1xθ2y1θ3z2θ1x1θ2yθ2z3+θ1xθ2yθ3z4P(X = x, Y = y) = \theta_{1}^{x - 1} \theta_{2}^{y - 1} \theta_{3}^{z_1} - \theta_{1}^{x} \theta_{2}^{y - 1} \theta_{3}^{z_2} - \theta_{1}^{x - 1} \theta_{2}^{y} \theta_{2}^{z_3} + \theta_{1}^{x} \theta_{2}^{y} \theta_{3}^{z_4}

where x,y>0x,y > 0 are positive integers and z1=max(x1,y1),z2=max(x,y1),z3=max(x1,y),z4=max(x,y)z_1 = \max(x - 1, y - 1),z_2 = \max(x, y - 1), z_3 = \max(x - 1, y), z_4 = \max(x, y). The second form is given by the conditions:

If X < Y, then

P(X=x,Y=y)=θ1x1(θ2θ3)y1(1θ2θ3)(1θ1)P(X = x, Y = y) = \theta_1^{x - 1} (\theta_2 \theta_{3})^{y - 1}(1 - \theta_{2} \theta_{3}) (1 - \theta_1)

If X = Y, then

P(X=x,Y=y)=(θ1θ2θ3)x1(1θ1θ3θ2θ3+θ1θ2θ3)P(X = x, Y = y) = (\theta_1 \theta_2 \theta_{3})^{x - 1}(1 - \theta_1 \theta_{3} - \theta_2 \theta_{3} + \theta_1 \theta_2 \theta_{3})

If X > Y, then

P(X=x,Y=y)=θ2y1(θ1θ3)x1(1θ1θ3)(1θ2)P(X = x, Y = y) = \theta_2^{y - 1} (\theta_1 \theta_{3})^{x - 1}(1 - \theta_{1} \theta_{3}) (1 - \theta_2)

Value

dbivgeo1 gives the values of the probability mass function using the first form of the joint pmf.

dbivgeo2 gives the values of the probability mass function using the second form of the joint pmf.

Invalid arguments will return an error message.

Author(s)

Ricardo P. Oliveira [email protected]

Jorge Alberto Achcar [email protected]

dbivgeo1 and dbivgeo2 are calculated directly from the definitions.

References

Basu, A. P., & Dhar, S. K. (1995). Bivariate geometric distribution. Journal of Applied Statistical Science, 2, 1, 33-44.

Li, J., & Dhar, S. K. (2013). Modeling with bivariate geometric distributions. Communications in Statistics-Theory and Methods, 42, 2, 252-266.

Achcar, J. A., Davarzani, N., & Souza, R. M. (2016). Basu–Dhar bivariate geometric distribution in the presence of covariates and censored data: a Bayesian approach. Journal of Applied Statistics, 43, 9, 1636-1648.

de Oliveira, R. P., & Achcar, J. A. (2018). Basu-Dhar's bivariate geometric distribution in presence of censored data and covariates: some computational aspects. Electronic Journal of Applied Statistical Analysis, 11, 1, 108-136.

See Also

Geometric for the univariate geometric distribution.

Examples

# If x and y are integer numbers:

dbivgeo1(x = 1, y = 2, theta = c(0.2, 0.4, 0.7), log = FALSE)
# [1] 0.16128
dbivgeo2(x = 1, y = 2, theta = c(0.2, 0.4, 0.7), log = FALSE)
# [1] 0.16128

# If x is a matrix:

matr 	<- 	 matrix(c(1,2,3,5), ncol = 2)

dbivgeo1(x = matr, y = NULL, theta = c(0.2,0.4,0.7), log = FALSE)
# [1] 0.0451584000 0.0007080837
dbivgeo2(x = matr, y = NULL, theta = c(0.2,0.4,0.7), log = FALSE)
# [1] 0.0451584000 0.0007080837

# If log = TRUE:

dbivgeo1(x = 1, y = 2, theta = c(0.2, 0.4, 0.7), log = TRUE)
# [1] -1.824613
dbivgeo2(x = 1, y = 2, theta = c(0.2, 0.4, 0.7), log = TRUE)
# [1] -1.824613

Moments Estimator for the Basu-Dhar Bivariate Geometric Distribution

Description

This function computes the estimators based on the method of the moments for each parameter of the Basu-Dhar bivariate geometric distribution.

Usage

mombivgeo(x, y)

Arguments

x

matrix or vector containing the data. If x is a matrix then it is considered as x the first column and y the second column (y argument need be setted to NULL). Additional columns and y are ignored.

y

vector containing the data of y. It is used only if x is also a vector. Vectors x and y should be of equal length.

Details

The moments estimators of θ1,θ2,θ3\theta_1, \theta_2, \theta_3 of the Basu-Dhar bivariate geometric distribution are given by:

θ^1=Yˉ(1Wˉ)Wˉ(1Yˉ)\hat \theta_1 = \frac{\bar{Y}(1 - \bar{W})}{\bar{W}(1 - \bar{Y})}

θ^2=Xˉ(Wˉ1)Wˉ(Xˉ1)\hat \theta_2 = \frac{\bar{X}(\bar{W} - 1)}{\bar{W}(\bar{X} - 1)}

θ^3=Xˉ(Xˉ1)(Yˉ1)(Wˉ1)XˉYˉ\hat \theta_3 = \frac{\bar{X}(\bar{X} - 1)(\bar{Y} - 1)}{(\bar{W} - 1)\bar{X} \bar{Y}}

Value

mombivgeo gives the values of the moments estimator.

Invalid arguments will return an error message.

Author(s)

Ricardo P. Oliveira [email protected]

Jorge Alberto Achcar [email protected]

mombivgeo is calculated directly from the definition.

References

Basu, A. P., & Dhar, S. K. (1995). Bivariate geometric distribution. Journal of Applied Statistical Science, 2, 1, 33-44.

Li, J., & Dhar, S. K. (2013). Modeling with bivariate geometric distributions. Communications in Statistics-Theory and Methods, 42, 2, 252-266.

Achcar, J. A., Davarzani, N., & Souza, R. M. (2016). Basu–Dhar bivariate geometric distribution in the presence of covariates and censored data: a Bayesian approach. Journal of Applied Statistics, 43, 9, 1636-1648.

de Oliveira, R. P., & Achcar, J. A. (2018). Basu-Dhar's bivariate geometric distribution in presence of censored data and covariates: some computational aspects. Electronic Journal of Applied Statistical Analysis, 11, 1, 108-136.

See Also

Geometric for the univariate geometric distribution.

Examples

# Generate the data set:

set.seed(123)
x1 		<- 	rbivgeo1(n = 1000, theta = c(0.5, 0.5, 0.7))
set.seed(123)
x2 		<- 	rbivgeo2(n = 1000, theta = c(0.5, 0.5, 0.7))

# Compute de moment estimator by:

mombivgeo(x = x1, y = NULL) # For data set x1
#             [,1]
# theta1 0.5053127
# theta2 0.5151873
# theta3 0.6640406

mombivgeo(x = x2, y = NULL) # For data set x2
#             [,1]
# theta1 0.4922327
# theta2 0.5001577
# theta3 0.6993893

Joint Cumulative Function for the Basu-Dhar Bivariate Geometric Distribution

Description

This function computes the joint cumulative function of the Basu-Dhar bivariate geometric distribution assuming arbitrary parameter values.

Usage

pbivgeo(x, y, theta, lower.tail = TRUE)

Arguments

x

matrix or vector containing the data. If x is a matrix then it is considered as x the first column and y the second column (y argument need be setted to NULL). Additional columns and y are ignored.

y

vector containing the data of y. It is used only if x is also a vector. Vectors x and y should be of equal length.

theta

vector (of length 3) containing values of the parameters θ1,θ2\theta_1, \theta_2 and θ3\theta_3 of the Basu-Dhar bivariate Geometric distribution. The parameters are restricted to 0<θi<1,i=1,20 < \theta_i < 1, i = 1,2 and 0<θ310 < \theta_3 \le 1.

lower.tail

logical; If TRUE (default), probabilities are P(Xx,Yy)P(X \le x, Y \le y) otherwise P(X>x,Y>y)P(X > x, Y > y).

Details

The joint cumulative function for a random vector (XX, YY) following a Basu-Dhar bivariate geometric distribution could be written as:

P(Xx,Yy)=1(θ1θ3)x(θ2θ3)y+θ1xθ2yθ3max(x,y)P(X \le x, Y \le y) = 1 - (\theta_{1}\theta_3)^{x} - (\theta_{2}\theta_3)^{y} + \theta_{1}^{x}\theta_{2}^{y} \theta_{3}^{\max(x,y)}

and the joint survival function is given by:

P(X>x,Y>y)=θ1xθ2yθ3max(x,y)P(X > x, Y > y) = \theta_{1}^{x}\theta_{2}^{y} \theta_{3}^{\max(x,y)}

Value

pbivgeo gives the values of the cumulative function.

Invalid arguments will return an error message.

Author(s)

Ricardo P. Oliveira [email protected]

Jorge Alberto Achcar [email protected]

pbivgeo is calculated directly from the definition.

References

Basu, A. P., & Dhar, S. K. (1995). Bivariate geometric distribution. Journal of Applied Statistical Science, 2, 1, 33-44.

Li, J., & Dhar, S. K. (2013). Modeling with bivariate geometric distributions. Communications in Statistics-Theory and Methods, 42, 2, 252-266.

Achcar, J. A., Davarzani, N., & Souza, R. M. (2016). Basu–Dhar bivariate geometric distribution in the presence of covariates and censored data: a Bayesian approach. Journal of Applied Statistics, 43, 9, 1636-1648.

de Oliveira, R. P., & Achcar, J. A. (2018). Basu-Dhar's bivariate geometric distribution in presence of censored data and covariates: some computational aspects. Electronic Journal of Applied Statistical Analysis, 11, 1, 108-136.

See Also

Geometric for the univariate geometric distribution.

Examples

# If x and y are integer numbers:

pbivgeo(x = 1, y = 2, theta = c(0.2, 0.4, 0.7), lower.tail = TRUE)
# [1] 0.79728

# If x is a matrix:

matr 	<- 	 matrix(c(1,2,3,5), ncol = 2)
pbivgeo(x = matr, y = NULL, theta = c(0.2,0.4,0.7), lower.tail = TRUE)
# [1] 0.8424384 0.9787478

# If lower.tail = FALSE:

pbivgeo(x = 1, y = 2, theta = c(0.2, 0.4, 0.7), lower.tail = FALSE)
# [1] 0.01568

matr 	<- 	 matrix(c(1,2,3,5), ncol = 2)
pbivgeo(x = matr, y = NULL, theta = c(0.9,0.4,0.7), lower.tail = FALSE)
# [1] 0.01975680 0.00139404

Generates Random Deviates from the Basu-Dhar Bivariate Geometric Distribution

Description

This function generates random values from the Basu-Dhar bivariate geometric distribution assuming arbitrary parameter values.

Usage

rbivgeo1(n, theta)
rbivgeo2(n, theta)

Arguments

n

number of observations. If length(n) >1> 1, the length is taken to be the number required.

theta

vector (of length 3) containing values of the parameters θ1,θ2\theta_1, \theta_2 and θ3\theta_{3} of the Basu-Dhar bivariate Geometric distribution. The parameters are restricted to 0<θi<1,i=1,20 < \theta_i < 1, i = 1,2 and 0<θ310 < \theta_{3} \le 1.

Details

The conditional distribution of X given Y is given by:

If X < Y, then

P(X=xY=y)=θ1x1(1θ1)P(X = x | Y = y) = \theta_1^{x - 1}(1 - \theta_1)

If X = Y, then

P(X=xY=y)=θ1x1(1θ1θ3θ2θ3+θ1θ2θ3)1θ2θ3P(X = x | Y = y) = \frac{\theta_1^{x - 1}(1 - \theta_1 \theta_{3} - \theta_2 \theta_{3} + \theta_1 \theta_2 \theta_{3})}{1 - \theta_2 \theta_{3}}

If X > Y, then

P(X=xY=y)=θ1x1θ3xy(1θ1θ3)(1θ2)1θ2θ3P(X = x | Y = y) = \frac{\theta_1^{x - 1} \theta_{3}^{x - y}(1 - \theta_{1} \theta_{3}) (1 - \theta_2)}{1 - \theta_2 \theta_{3}}

Value

rbivgeo1 and rbivgeo2 generate random deviates from the Bash-Dhar bivariate geometric distribution. The length of the result is determined by n, and is the maximum of the lengths of the numerical arguments for the other functions.

Invalid arguments will return an error message.

Author(s)

Ricardo P. Oliveira [email protected]

Jorge Alberto Achcar [email protected]

rbivgeo1 generates random deviates using the inverse transformation method. Returns a matrix that the first column corresponds to X generated random values and the second column corresponds to Y generated random values.

rbivgeo2 generates random deviates using the shock model. Returns a matrix that the first column corresponds to X generated random values and the second column corresponds to Y generated random values. See Marshall and Olkin (1967) for more details.

References

Marshall, A. W., & Olkin, I. (1967). A multivariate exponential distribution. Journal of the American Statistical Association, 62, 317, 30-44.

Basu, A. P., & Dhar, S. K. (1995). Bivariate geometric distribution. Journal of Applied Statistical Science, 2, 1, 33-44.

Li, J., & Dhar, S. K. (2013). Modeling with bivariate geometric distributions. Communications in Statistics-Theory and Methods, 42, 2, 252-266.

Achcar, J. A., Davarzani, N., & Souza, R. M. (2016). Basu–Dhar bivariate geometric distribution in the presence of covariates and censored data: a Bayesian approach. Journal of Applied Statistics, 43, 9, 1636-1648.

de Oliveira, R. P., & Achcar, J. A. (2018). Basu-Dhar's bivariate geometric distribution in presence of censored data and covariates: some computational aspects. Electronic Journal of Applied Statistical Analysis, 11, 1, 108-136.

See Also

Geometric for the univariate geometric distribution.

Examples

rbivgeo1(n = 10, theta = c(0.5, 0.5, 0.7))
#       [,1] [,2]
#  [1,]    2    1
#  [2,]    3    1
#  [3,]    1    1
#  [4,]    1    1
#  [5,]    2    2
#  [6,]    1    3
#  [7,]    2    2
#  [8,]    1    1
#  [9,]    1    1
# [10,]    2    2

rbivgeo2(n = 10, theta = c(0.5, 0.5, 0.7))
#       [,1] [,2]
#  [1,]    1    1
#  [2,]    2    1
#  [3,]    2    1
#  [4,]    4    1
#  [5,]    1    1
#  [6,]    2    2
#  [7,]    3    2
#  [8,]    3    1
#  [9,]    3    2
# [10,]    1    1